@@ -8,7 +8,7 @@ use warnings;
 use Moo;
 use Scalar::Util qw(blessed);
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 has node => (
     is       => 'ro',
@@ -41,6 +41,7 @@ has precision     => ( is => 'rwp' );
 has not_null      => ( is => 'rwp' );
 has autoincrement => ( is => 'rwp' );
 has default_value => ( is => 'rwp' );
+has comment       => ( is => 'rwp' );
 
 
 sub as_hash {
@@ -48,7 +49,7 @@ sub as_hash {
 
     my %info;
 
-    for my $attr ( qw(name length datatype precision not_null autoincrement default_value) ) {
+    for my $attr ( qw(name length datatype precision not_null autoincrement default_value comment) ) {
         $info{$attr} = $self->$attr();
     }
 
@@ -63,7 +64,7 @@ sub _parse {
     my $id = $node->findvalue( '@id' );
     $self->_set_id( $id );
 
-    for my $key ( qw(name length precision) ) {
+    for my $key ( qw(name length precision comment) ) {
         my $value  = $node->findvalue( './value[@key="' . $key . '"]' );
         my $method = $self->can( '_set_' . $key );
         $self->$method( $value );
@@ -99,7 +100,7 @@ MySQL::Workbench::Parser::Column - A column of the ER model
 
 =head1 VERSION
 
-version 0.06
+version 1.01
 
 =for Pod::Coverage BUILD
 
@@ -121,13 +122,41 @@ returns
         default_value => '',
     )
 
+=head1 ATTRIBUTES
+
+=over 4
+
+=item * autoincrement
+
+=item * comment
+
+=item * datatype
+
+=item * default_value
+
+=item * id
+
+=item * length
+
+=item * name
+
+=item * node
+
+=item * not_null
+
+=item * precision
+
+=item * table
+
+=back
+
 =head1 AUTHOR
 
 Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Renee Baecker.
+This software is Copyright (c) 2018 by Renee Baecker.
 
 This is free software, licensed under:
 
